==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/pages/custom-object/ViewCustomObject.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/pages/custom-object/ViewCustomObject.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', 'app-builder-web$react-router-dom', '../../components/control-menu/ControlMenu.es', '../../utils/client.es', '../app/EditApp.es', '../app/ListApps.es', '../form-view/EditFormView.es', '../form-view/ListFormViews.es', '../table-view/EditTableView.es', '../table-view/ListTableViews.es', './CustomObjectNavigationBar.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _ControlMenu = _interopRequireDefault(require("../../components/control-menu/ControlMenu.es"));

  var _client = require("../../utils/client.es");

  var _EditApp = _interopRequireDefault(require("../app/EditApp.es"));

  var _ListApps = _interopRequireDefault(require("../app/ListApps.es"));

  var _EditFormView = _interopRequireDefault(require("../form-view/EditFormView.es"));

  var _ListFormViews = _interopRequireDefault(require("../form-view/ListFormViews.es"));

  var _EditTableView = _interopRequireDefault(require("../table-view/EditTableView.es"));

  var _ListTableViews = _interopRequireDefault(require("../table-view/ListTableViews.es"));

  var _CustomObjectNavigationBar = _interopRequireDefault(require("./CustomObjectNavigationBar.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = function _default(_ref) {
    var _ref$match = _ref.match,
        dataDefinitionId = _ref$match.params.dataDefinitionId,
        path = _ref$match.path;

    var _useState = (0, _react.useState)(''),
        _useState2 = _slicedToArray(_useState, 2),
        title = _useState2[0],
        setTitle = _useState2[1];

    (0, _react.useEffect)(function () {
      (0, _client.getItem)("/o/data-engine/v2.0/data-definitions/".concat(dataDefinitionId)).then(function (dataDefinition) {
        return setTitle(dataDefinition.name.en_US);
      });
    }, [dataDefinitionId]);
    return _react["default"].createElement(_reactRouterDom.Switch, null, _react["default"].createElement(_reactRouterDom.Route, {
      component: _EditFormView["default"],
      path: ["".concat(path, "/form-views/add"), "".concat(path, "/form-views/:dataLayoutId(\\d+)")]
    }), _react["default"].createElement(_reactRouterDom.Route, {
      component: _EditTableView["default"],
      path: ["".concat(path, "/table-views/add"), "".concat(path, "/table-views/:dataListViewId(\\d+)")]
    }), _react["default"].createElement(_reactRouterDom.Route, {
      component: _EditApp["default"],
      path: ["".concat(path, "/apps/deploy"), "".concat(path, "/apps/:appId(\\d+)")]
    }), _react["default"].createElement(_reactRouterDom.Route, {
      path: path,
      render: function render() {
        return _react["default"].createElement(_react["default"].Fragment, null, _react["default"].createElement(_ControlMenu["default"], {
          backURL: "/",
          title: title
        }), _react["default"].createElement(_CustomObjectNavigationBar["default"], null), _react["default"].createElement(_reactRouterDom.Switch, null, _react["default"].createElement(_reactRouterDom.Route, {
          component: _ListFormViews["default"],
          path: "".concat(path, "/form-views")
        }), _react["default"].createElement(_reactRouterDom.Route, {
          component: _ListTableViews["default"],
          path: "".concat(path, "/table-views")
        }), _react["default"].createElement(_reactRouterDom.Route, {
          component: _ListApps["default"],
          path: "".concat(path, "/apps")
        })));
      }
    }));
  };

  exports["default"] = _default;
  //# sourceMappingURL=ViewCustomObject.es.js.map
});
//# sourceMappingURL=ViewCustomObject.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/custom-object/ViewCustomObject.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/custom-object/ViewCustomObject.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', 'app-builder-web$react-router-dom', '../../components/control-menu/ControlMenu.es', '../../utils/client.es', '../app/EditApp.es', '../app/ListApps.es', '../form-view/EditFormView.es', '../form-view/ListFormViews.es', '../table-view/EditTableView.es', '../table-view/ListTableViews.es', './CustomObjectNavigationBar.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _ControlMenu = _interopRequireDefault(require("../../components/control-menu/ControlMenu.es"));

  var _client = require("../../utils/client.es");

  var _EditApp = _interopRequireDefault(require("../app/EditApp.es"));

  var _ListApps = _interopRequireDefault(require("../app/ListApps.es"));

  var _EditFormView = _interopRequireDefault(require("../form-view/EditFormView.es"));

  var _ListFormViews = _interopRequireDefault(require("../form-view/ListFormViews.es"));

  var _EditTableView = _interopRequireDefault(require("../table-view/EditTableView.es"));

  var _ListTableViews = _interopRequireDefault(require("../table-view/ListTableViews.es"));

  var _CustomObjectNavigationBar = _interopRequireDefault(require("./CustomObjectNavigationBar.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = function _default(_ref) {
    var _ref$match = _ref.match,
        dataDefinitionId = _ref$match.params.dataDefinitionId,
        path = _ref$match.path;

    var _useState = (0, _react.useState)(''),
        _useState2 = _slicedToArray(_useState, 2),
        title = _useState2[0],
        setTitle = _useState2[1];

    (0, _react.useEffect)(function () {
      (0, _client.getItem)("/o/data-engine/v2.0/data-definitions/".concat(dataDefinitionId)).then(function (dataDefinition) {
        return setTitle(dataDefinition.name.en_US);
      });
    }, [dataDefinitionId]);
    return _react["default"].createElement(_reactRouterDom.Switch, null, _react["default"].createElement(_reactRouterDom.Route, {
      component: _EditFormView["default"],
      path: ["".concat(path, "/form-views/add"), "".concat(path, "/form-views/:dataLayoutId(\\d+)")]
    }), _react["default"].createElement(_reactRouterDom.Route, {
      component: _EditTableView["default"],
      path: ["".concat(path, "/table-views/add"), "".concat(path, "/table-views/:dataListViewId(\\d+)")]
    }), _react["default"].createElement(_reactRouterDom.Route, {
      component: _EditApp["default"],
      path: ["".concat(path, "/apps/deploy"), "".concat(path, "/apps/:appId(\\d+)")]
    }), _react["default"].createElement(_reactRouterDom.Route, {
      path: path,
      render: function render() {
        return _react["default"].createElement(_react["default"].Fragment, null, _react["default"].createElement(_ControlMenu["default"], {
          backURL: "/",
          title: title
        }), _react["default"].createElement(_CustomObjectNavigationBar["default"], null), _react["default"].createElement(_reactRouterDom.Switch, null, _react["default"].createElement(_reactRouterDom.Route, {
          component: _ListFormViews["default"],
          path: "".concat(path, "/form-views")
        }), _react["default"].createElement(_reactRouterDom.Route, {
          component: _ListTableViews["default"],
          path: "".concat(path, "/table-views")
        }), _react["default"].createElement(_reactRouterDom.Route, {
          component: _ListApps["default"],
          path: "".concat(path, "/apps")
        })));
      }
    }));
  };

  exports["default"] = _default;
  //# sourceMappingURL=ViewCustomObject.es.js.map
});
//# sourceMappingURL=ViewCustomObject.es.js.map
